==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ja\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "ユーザー"

]
, "Groups"
: "グループ"

, "Roles"
: "役割"

, "Applications"
: "アプリケーション"

, "Containers"
: ""

, "Shared Tags"
: "共有タグ"

, "Customfields"
: ""

, "Computers"
: ""

, "Access Log, Access Logs"
: [
  "アクセスログ"

]
, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "Admin"
: "管理者"

, "Refresh"
: ""

, "Name"
: "名前"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  ""

]
, "Default Addressbook for new contacts and groups"
: ""

, "Group, Groups"
: [
  "グループ"

]
, "Application, Applications"
: [
  ""

]
, "Config, Configs"
: [
  ""

]
, "Configs"
: ""

, "Please wait"
: "お待ちください"

, "Updating Memberships"
: "メンバーシップをアップデートしています"

, "Failed"
: "失敗"

, "Could not save group."
: "グループを保存できませんでした"

, "Errors"
: "エラー"

, "Please fix the errors noted."
: "表示されているエラーを修正してください"

, "Group Name"
: "グループ名"

, "Description"
: "説明"

, "Visibility"
: ""

, "Display in addressbook"
: "アドレス帳に表示する"

, "Hide from addressbook"
: "アドレス帳に表示しない"

, "Saved in Addressbook"
: "アドレス帳に保存"

, "Group Members"
: "グループメンバー"

, "Transferring {0}..."
: "{0}の転送中..."

, "Add new group"
: "新規グループの追加"

, "Edit Group \"{0}\""
: "グループの編集 \"{0}\""

, "Enable Application"
: "アプリケーションを有効にする"

, "Disable Application"
: "アプリケーションを無効にする"

, "Settings"
: "設定"

, "{0} Settings"
: "{0}の設定"

, "enable application"
: "アプリケーションを有効にする"

, "disable application"
: "アプリケーションを無効にする"

, "settings"
: "設定"

, "Search:"
: "検索："

, "disabled"
: "無効"

, "enabled"
: "有効"

, "unknown status ({0})"
: "不明なステータス ({0})"

, "Displaying application {0} - {1} of {2}"
: "アプリケーションの表示 {0} - {1} 件中 {2}"

, "No applications to display"
: "表示するアプリケーションがありません"

, "Order"
: "並び順"

, "Status"
: "ステータス"

, "Version"
: "バージョン"

, "Confirm"
: "確認"

, "Do you really want to delete the selected groups?"
: "本当に選択したグループを削除しますか？"

, "Deleting group(s)..."
: "グループを削除しています..."

, "Some error occurred while trying to delete the group."
: "グループの削除中にエラーが発生しました"

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "グループの表示 {0} - {1} 件中 {2}"

, "No groups to display"
: "表示するグループがありません"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "コンピューター名"

, "IP Address"
: "ＩＰアドレス"

, "Login Time"
: "ログイン時間"

, "Logout Time"
: "ログアウト時間"

, "Client Type"
: ""

, "Session ID"
: "セッションＩＤ"

, "Login Name"
: "ログイン名"

, "Result"
: "結果"

, "user blocked"
: "ユーザーはブロックされています"

, "password expired"
: "パスワードの有効期限が切れました"

, "user disabled"
: "ユーザーは無効になっています"

, "invalid password"
: "パスワードが違います"

, "ambiguous username"
: "あいまいなユーザ名"

, "user not found"
: "ユーザが見つかりません"

, "failure"
: "失敗"

, "success"
: "成功"

, "Could not save role."
: "ロールを保存できませんでした"

, "Deleting role..."
: "ロールを削除しています..."

, "Some error occurred while trying to delete the role."
: "ロールの削除中にエラーが発生しました"

, "Rights"
: "権限"

, "Members"
: "メンバー"

, "Role Name"
: "役割名"

, "Role"
: ""

, "Add New Role"
: "役割の追加"

, "Edit Role \"{0}\""
: "役割の編集 \"{0}\""

, "Container Name"
: "コンテナ名"

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  "コンテナ"

]
, "Model"
: ""

, "personal"
: "個人用"

, "shared"
: "共有"

, "Color"
: "色"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Do you really want to delete the selected roles?"
: "選択されたロールを本当に削除しますか？"

, "Deleting role(s)..."
: "ロールを削除しています..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "ロールの表示 {0} - {1} 件中 {2}"

, "No roles to display"
: "表示するロールがありません"

, "Do you really want to delete the selected tags?"
: "選択されたタグを本当に削除しますか？"

, "Deleting tag(s)..."
: "タグを削除しています..."

, "Add Tag"
: "タグの追加"

, "Edit Tag"
: "タグの編集"

, "Delete Tag"
: "タグの削除"

, "Displaying tags {0} - {1} of {2}"
: "タグの表示 {0} - {1} 件中 {2}"

, "No tags to display"
: "表示するタグがありません"

, "Usage:&#160;"
: ""

, "Label"
: ""

, "Value"
: "値"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "キャンセル"

, "OK"
: ""

, "Configure store"
: "ストアの設定"

, "Custom field definition"
: "カスタムフィールドの定義"

, "Text"
: "テキスト"

, "Textarea"
: ""

, "Number"
: "数値"

, "Date"
: "日付"

, "DateTime"
: "日付時刻"

, "Time"
: "時刻"

, "Boolean"
: "真偽値"

, "Search Combo"
: ""

, "Key Field"
: "キーフィールド"

, "Record"
: "レコード"

, "Record List"
: ""

, "Length"
: "長さ"

, "Required"
: "必須項目"

, "Custom field additional properties"
: "カスタムフィールドの追加属性"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "カスタムフィールドは既に登録されています。別の名前を使用してください。"

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "姓"

, "First name"
: "名"

, "Email"
: "Eメール"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: "前回のログイン"

, "Last login from"
: "前回のログイン（From)"

, "Password changed"
: "パスワード変更"

, "Expires"
: "期間"

, "Set new password"
: "新しいパスワードの設定"

, "Please enter the new password:"
: "新しいパスワードを入力してください"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "プライマリーグループ"

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Logon Time"
: ""

, "never logged in"
: "ログインしていません"

, "Home Path"
: ""

, "Logoff Time"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: "未"

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: ""

, "Add an alias address..."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: ""

, "Email Forward"
: ""

, "Add a forward address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "Password"
: "パスワード"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: "パスワード設定"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: "タグ({0})は保存できませんでした"

, "Allowed Contexts"
: "許可されたコンテキスト"

, "Context"
: "コンテキスト"

, "Account Rights"
: "アカウントの権限"

, "View"
: "表示"

, "Use"
: "使用"

, "Tag Name"
: "タグ名"

, "Tag"
: "タグ"

, "Add New Tag"
: "タグの新規追加"

, "Edit Tag \"{0}\""
: "タグの編集 \"{0}\""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "アクセスログの管理"

, "delete access log entries"
: "アクセスログエントリの削除"

, "manage accounts"
: "アカウントの管理"

, "add and edit users and groups, add group members, change user passwords"
: "グループとユーザの追加と編集、グループにメンバーの追加、ユーザパスワードの変更"

, "manage applications"
: "アプリケーションの管理"

, "enable and disable applications, edit application settings"
: "アプリケーションの有効無効、アプリケーション設定の編集"

, "manage roles"
: "役割の管理"

, "add and edit roles, add new members to roles, add application rights to roles"
: "ロールの追加と編集、メンバーにロールの新規追加、アプリケーション権限のロールへの付与"

, "manage shared tags"
: "共有タグの管理"

, "add, delete and edit shared tags"
: "共有タグの追加、削除と編集"

, "manage computers"
: "コンピュータの管理"

, "add, delete and edit (samba) computers"
: "コンピュータの追加、削除、編集(samba)"

, "manage containers"
: "コンテナの管理"

, "add, delete and edit containers and manage container grants"
: "コンテナの追加、削除、編集及び権限の管理"

, "manage customfields"
: "カスタムフィールドの管理"

, "add and edit customfields"
: "カスタムフィールドの追加/編集"

, "view access log"
: "アクセスログの閲覧"

, "view access log list"
: "アクセスログ一覧の閲覧"

, "view accounts"
: "アカウントの閲覧"

, "view accounts list and details"
: "アカウント一覧と詳細の閲覧"

, "view applications"
: "アプリケーションの閲覧"

, "view applications list and details"
: "アプリケーションの一覧と詳細の閲覧"

, "view roles"
: "役割の閲覧"

, "view roles list and details"
: "役割の一覧と詳細の閲覧"

, "view computers"
: ""

, "view computers list and details"
: "コンピュータの一覧と詳細"

, "view containers"
: "コンテナを見る"

, "view personal and shared containers"
: "個人と共有のコンテナを見る"

, "view customfields"
: "カスタムフィールドを見る"

, "view customfields list"
: "カスタムフィールドの一覧を見る"

, "view serverinfo"
: "サーバ情報を見る"

, "view serverinfo list"
: "サーバ情報の一覧を見る"

, "view quota usage"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Could not save tag without (view-)rights"
: ""

, "User"
: "ユーザー"

, "Access Log"
: "アクセスログ"

, "Computer"
: ""

, "Group"
: "グループ"

, "Application"
: ""

, "Config"
: ""

, "Container"
: "コンテナ"

, "Customfield"
: ""

, "Samba User"
: ""

, "Email User"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-ja-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Japanese (http://www.transifex.com/tine20/tine20/language/ja/)\nLanguage: ja\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "アプリケーションを有効にする"

, "Disable Application"
: "アプリケーションを無効にする"

, "Settings"
: "設定"

, "{0} Settings"
: "{0}の設定"

, "Search:"
: "検索："

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "アプリケーションの表示 {0} - {1} 件中 {2}"

, "No applications to display"
: "表示するアプリケーションがありません"

, "Order"
: "並び順"

, "Name"
: "名前"

, "Status"
: "ステータス"

, "Version"
: "バージョン"

, "Confirm"
: "確認"

, "Do you really want to delete the selected groups?"
: "本当に選択したグループを削除しますか？"

, "Deleting group(s)..."
: "グループを削除しています..."

, "Failed"
: "失敗"

, "Some error occurred while trying to delete the group."
: "グループの削除中にエラーが発生しました"

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "グループの表示 {0} - {1} 件中 {2}"

, "No groups to display"
: "表示するグループがありません"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "説明"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "エラー"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "キャンセル"

, "OK"
: ""

, "Configure store"
: "ストアの設定"

, "Model"
: ""

, "Custom field definition"
: "カスタムフィールドの定義"

, "Text"
: "テキスト"

, "Textarea"
: ""

, "Number"
: "数値"

, "Date"
: "日付"

, "DateTime"
: "日付時刻"

, "Time"
: "時刻"

, "Boolean"
: "真偽値"

, "Search Combo"
: ""

, "Key Field"
: "キーフィールド"

, "Record"
: "レコード"

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: "長さ"

, "Required"
: "必須項目"

, "Custom field additional properties"
: "カスタムフィールドの追加属性"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "グループ"

]
, "Customfield already exists. Please choose another name."
: "カスタムフィールドは既に登録されています。別の名前を使用してください。"

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""

]
, "Value"
: "値"

, "Default ({0})"
: ""

, "Computer Name"
: "コンピューター名"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "お待ちください"

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: "タグ({0})は保存できませんでした"

, "Please fix the errors noted."
: "表示されているエラーを修正してください"

, "Allowed Contexts"
: "許可されたコンテキスト"

, "Context"
: "コンテキスト"

, "Account Rights"
: "アカウントの権限"

, "View"
: "表示"

, "Use"
: "使用"

, "Tag Name"
: "タグ名"

, "Color"
: "色"

, "Transferring {0}..."
: "{0}の転送中..."

, "Tag"
: "タグ"

, "Add New Tag"
: "タグの新規追加"

, "Edit Tag \"{0}\""
: "タグの編集 \"{0}\""

, "Do you really want to delete the selected tags?"
: "選択されたタグを本当に削除しますか？"

, "Deleting tag(s)..."
: "タグを削除しています..."

, "Add Tag"
: "タグの追加"

, "Edit Tag"
: "タグの編集"

, "Delete Tag"
: "タグの削除"

, "Displaying tags {0} - {1} of {2}"
: "タグの表示 {0} - {1} 件中 {2}"

, "No tags to display"
: "表示するタグがありません"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "メンバーシップをアップデートしています"

, "Could not save role."
: "ロールを保存できませんでした"

, "Deleting role..."
: "ロールを削除しています..."

, "Some error occurred while trying to delete the role."
: "ロールの削除中にエラーが発生しました"

, "Rights"
: "権限"

, "Members"
: "メンバー"

, "Role Name"
: "役割名"

, "Role"
: ""

, "Add New Role"
: "役割の追加"

, "Edit Role \"{0}\""
: "役割の編集 \"{0}\""

, "Do you really want to delete the selected roles?"
: "選択されたロールを本当に削除しますか？"

, "Deleting role(s)..."
: "ロールを削除しています..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "ロールの表示 {0} - {1} 件中 {2}"

, "No roles to display"
: "表示するロールがありません"

, "Access Log, Access Logs"
: [
  "アクセスログ"

]
, "Groups"
: "グループ"

, "Applications"
: "アプリケーション"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: "プライマリーグループ"

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: "ログイン時間"

, "never logged in"
: "ログインしていません"

, "Home Path"
: ""

, "Logout Time"
: "ログアウト時間"

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: "未"

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "First name"
: "名"

, "Last name"
: "姓"

, "Login name"
: ""

, "Password"
: "パスワード"

, "OpenID"
: ""

, "enabled"
: "有効"

, "disabled"
: "無効"

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "期間"

, "Visibility"
: ""

, "Display in addressbook"
: "アドレス帳に表示する"

, "Hide from addressbook"
: "アドレス帳に表示しない"

, "Saved in Addressbook"
: "アドレス帳に保存"

, "Last login at"
: "前回のログイン"

, "don't know"
: ""

, "Last login from"
: "前回のログイン（From)"

, "Password set"
: "パスワード設定"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  "ユーザー"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "パスワード変更"

, "Set new password"
: "新しいパスワードの設定"

, "Please enter the new password:"
: "新しいパスワードを入力してください"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "グループ名"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "グループメンバー"

, "personal"
: "個人用"

, "shared"
: "共有"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "コンテナ"

]
, "Container Name"
: "コンテナ名"

, "Container Order"
: ""

, "Computer, Computers"
: [
  ""

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "役割"

, "Containers"
: ""

, "Shared Tags"
: "共有タグ"

, "Customfields"
: ""

, "Computers"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "管理者"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "ＩＰアドレス"

, "Client Type"
: ""

, "Session ID"
: "セッションＩＤ"

, "Login Name"
: "ログイン名"

, "Result"
: "結果"

, "user blocked"
: "ユーザーはブロックされています"

, "password expired"
: "パスワードの有効期限が切れました"

, "user disabled"
: "ユーザーは無効になっています"

, "invalid password"
: "パスワードが違います"

, "ambiguous username"
: "あいまいなユーザ名"

, "user not found"
: "ユーザが見つかりません"

, "failure"
: "失敗"

, "success"
: "成功"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""








































, "Application"
: ""

, "Group"
: "グループ"

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: "アクセスログ"

, "User"
: "ユーザー"

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: "コンテナ"

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
